* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Developer Guide](https://help.sap.com/docs/leanix/ea/developer-guide)
  * Reporting Framework and CLI
